@@ -2,3 +2,5 @@ from . lgc import logic
 from . evd import basic
 from . con import cdist
 from . tbl import table
+from . bpl import BPL
+from . tools import C
