@@ -12,7 +12,7 @@ def P(f, l, r):
 
 def cdist(f, l, r):
     f = sp.sympify(f)
-    c, = sp.solve(sp.integrate(f, ('x', l, r))-1)
-    f = f.subs('c', c)
+    с, = sp.solve(sp.integrate(f, ('x', l, r))-1)
+    f = f.subs('с', с)
     x, = f.free_symbols
-    return {'C': c, 'E': E(x, f, l, r), 'D': D(x, f, l, r)}, P(f, l, r)
+    return {'c': с, 'E': E(x, f, l, r), 'D': D(x, f, l, r)}, P(f, l, r)
